@@ -1,6 +1,8 @@
+mod extensions;
 mod nu;
 mod periodic_table;
 mod periodic_table_grid;
 
+pub use extensions::{GroupBlockExt, StateOfMatterExt};
 pub use periodic_table::PeriodicTable;
 pub use periodic_table_grid::PERIODIC_TABLE_GRID;
